@@ -8,9 +8,9 @@ from ..rule.rule import Rule
 class RuleSet(ABC):
     def __init__(self, rules_list: List[Rule] = None):
         if rules_list is None:
-            self._rules = []
+            self.rules = []
         else:
-            self._rules = rules_list
+            self.rules = rules_list
 
     def __add__(self, other: "RuleSet"):
         rules = list(set(self.rules + other.rules))
@@ -22,14 +22,6 @@ class RuleSet(ABC):
     def __eq__(self, other: "RuleSet"):
         return set(self.rules) == set(other.rules)
 
-    @property
-    def rules(self) -> List[Rule]:
-        return self._rules
-
-    @rules.setter
-    def rules(self, value: List[Rule]):
-        self._rules = value
-
     # noinspection PyProtectedMember
     def calc_coverage_rate(self, xs: np.ndarray = None):
         if len(self) == 0:
@@ -38,7 +30,7 @@ class RuleSet(ABC):
             if xs is None:
                 rs_activation = reduce(lambda a, b: a._activation + b._activation, self.rules)
             else:
-                rs_activation = reduce(lambda a, b: a.condition.evaluate(xs) + b.condition.evaluate(xs), self.rules)
+                rs_activation = reduce(lambda a, b: a._condition.evaluate(xs) + b._condition.evaluate(xs), self.rules)
 
             # noinspection PyUnresolvedReferences
             return rs_activation.coverage_rate
